@@ -6,7 +6,7 @@ Matchering
 
 Audio Matching and Mastering Python Library
 
-:copyright: (C) 2016-2021 Sergree
+:copyright: (C) 2016-2022 Sergree
 :license: GPLv3, see LICENSE for more details.
 
 """
@@ -14,13 +14,13 @@ Audio Matching and Mastering Python Library
 __title__ = "matchering"
 
 __author__ = "Sergree"
-__credits__ = ["Sergey Grishakov", "Igor Isaev", "Chin Yun Yu", "Elizaveta Grishakova"]
+__credits__ = ["Sergey Grishakov", "Igor Isaev", "Chin Yun Yu", "Elizaveta Grishakova", "Zicklag"]
 __maintainer__ = "Sergree"
-__email__ = "wokashi.rg@gmail.com"
+__email__ = "sergree@vk.com"
 __license__ = "GPLv3"
-__copyright__ = "Copyright (C) 2016-2021 Sergree"
+__copyright__ = "Copyright (C) 2016-2022 Sergree"
 
-__version__ = "2.0.3"
+__version__ = "2.0.4"
 
 from .log.handlers import set_handlers as log
 from .results import Result, pcm16, pcm24
